This is a skill about doing things.

It helps with stuff. You might want to consider using it when you need help.

You should possibly try it out. It could maybe be useful for some tasks.

Remember to always test your code. Don't forget to save your files.

TODO: add more content here
FIXME: this section needs work
